<?

 /*************************************************************************************
 * Filename: setup.php
 *
 * This file is part of the Forum JAS plugin.
 * Copyright 2003-2016 by Matthijs Schuurman
 *
 * The Forum JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/forum/
 *************************************************************************************/


 class Plugin_Setup_forum extends Base_Plugin_Setup
 {
  function init()
  {
   //create modules
   $this->modules();

   return true;
  }

  function postSetup()
  {
   global $_config;
   
   //find forum category
   $d=Data::cache("categories", "view", "all");
   $d->setValue("name", "Forum");

   if(!$d->get())
   {
    $this->e->add($d->e);
    return false;
   }

   if($d->next()) 
    $this->e->add("Forum base categories already setup", "warning");
   else //forum category doesn't exist yet
   {
    $d->setExtra("list");
    $d->clearValues();

    //get global root category
    $d->setShowFields("nr");
    $d->setValue("show_total", 1);
    $d->setValue("catnr", 0);

    if(!$d->get()||!$d->next())
    {
     $this->e->add($d->e);
     return false;
    }

    $catnr=$d->v["nr"]; 


    //add root forum category
    $d->setAction("add");
    $d->setExtra("item");
    $d->clearValues();

    $d->setValue("catnr", $catnr);
    $d->setValue("name", "Forum");
    $d->setValue("text", $_config->get("title")." forum");
    $d->setValue("moduleLock", true);
    $d->setValue("module", Array("forum_categories"));

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }

    $catnr=$d->getValue("nr");


    //add forum users category
    $d->clearValues();

    $d->setValue("catnr", $catnr);
    $d->setValue("name", "Users");
    $d->setValue("text", "Forum users");
    $d->setValue("moduleLock", true);
    $d->setValue("module", $_config->get("usermodule"));

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }

    $usersnr=$d->getValue("nr");


    //add forum moderator category
    $d->clearValues();

    $d->setValue("catnr", $catnr);
    $d->setValue("name", "Moderators");
    $d->setValue("text", "Forum moderators");
    $d->setValue("moduleLock", true);
    $d->setValue("module", $_config->get("usermodule"));

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }

    $modsnr=$d->getValue("nr");


    //add forum admins category
    $d->clearValues();

    $d->setValue("catnr", $catnr);
    $d->setValue("name", "Admins");
    $d->setValue("text", "Forum admins");
    $d->setValue("moduleLock", true);
    $d->setValue("module", $_config->get("usermodule"));

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }

    $adminsnr=$d->getValue("nr");


    //Forum categories
    $d=Data::cache("forum_categories", "add", "item");
    $cats=Array();

    //add General forum category
    $d->setValue("catnr", $catnr);
    $d->setValue("name", "General discussion");
    $d->setValue("text", "General discussion about pretty much everything that doesn't fall in the other categories.");
    $d->setValue("moduleLock", true);
    $d->setValue("module", Array("forum_categories", "forum_threads"));

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }

    $cats[]=$d->getValue("nr");


    //add Feedback forum category
    $d->setValue("catnr", $catnr);
    $d->setValue("name", "Feedback");
    $d->setValue("text", "Post your questions, suggestion and comment about the forum or the site in general here.");
    $d->setValue("moduleLock", true);
    $d->setValue("module", Array("forum_categories", "forum_threads"));

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }

    $cats[]=$d->getValue("nr");


    //setup rights
    $d=Data::cache("categories", "rights", "item");

    $c=0;
    foreach($cats as $cat)
    {
     //users
     $d->setValue("nr", $cat, $c);
     $d->setValue("groupnr", $usersnr, $c);
     $d->setValue("rights", "1000000011000000", $c); //view cat, view+add threads
     $c++;

     //moderators
     $d->setValue("nr", $cat, $c);
     $d->setValue("groupnr", $modsnr, $c);
     $d->setValue("rights", "1110000011100000", $c); //view+add+edit cat, view+add+edit threads
     $c++;

     //admins
     $d->setValue("nr", $cat, $c);
     $d->setValue("groupnr", $adminsnr, $c);
     $d->setValue("rights", "1111110011111000", $c); //view+add+edit+delete+owner+rights cat, view+add+edit+delete+owner threads
     $c++;
    }

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }


    //Forum threads
    $d=Data::cache("forum_threads", "add", "item");

    //add post in General forum category
    $d->setValue("catnr", $cats[0]);
    $d->setValue("subject", "Welcome");
    $d->setValue("message", "You've successfully installed and set up the forum plugin. Happy posting!");
    $d->setValue("threadnr", 0);

    if(!$d->submit())
    {
     $this->e->add($d->e);
     return false;
    }


    //done
    $this->e->add("Forum base categories setup", "note");
   }

   return true;
  }


  function preDeSetup()
  {
   $this->e->add("Forum base categories not cleaned up", "warning");
   return true;
  }
   
 }
?>
